SyConversation class

associationId : "66666666666666666666666666666666" avatar : "" contact : {"avatar":"","birthday":null,"email":null,"extension":{"extension":"{"userId":666}","userId":666},"gender":"1","label":null,"mobile":null,"nickName":"官方消息","remark":null,"status":0,"type":0,"userId":"66666666666666666666666666666666"} key : "7155793691347525633_P_05b3dcc21d934283b2c493b8fbf88a7b_66666666666666666666666666666666_05b3dcc21d934283b2c493b8fbf88a7b" lastMessage : null localData : true name : "官方消息" needSyncMsg : 0 sendUserId : null sessionId : "7155793691347525633_P_05b3dcc21d934283b2c493b8fbf88a7b_66666666666666666666666666666666" sessionType : 1 syncMsgEndSeq : 0 syncMsgSeq : 0 topping : false unReadNum : 0 updateTimeStamp : 1709792558869

Constructors

SyConversation({String? associationId, String? avatar, SyContact? contact, String? key, SyMessage? lastMessage, SyMessage? latestTimeMessage, bool? localData, String? name, num? needSyncMsg, String? sendUserId, String? sessionId, SessionTypeEnum? sessionType, num? syncMsgEndSeq, num? syncMsgSeq, bool? topping, num? unReadNum, num? updateTimeStamp})
SyConversation.fromJson(dynamic json)

Properties

associationId String?
no setter
avatar String?
no setter
contact SyContact?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
key String?
no setter
lastMessage SyMessage?
no setter
latestTimeMessage SyMessage?
getter/setter pair
localData bool?
no setter
name String?
no setter
needSyncMsg num?
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendUserId String?
no setter
sessionId String?
no setter
sessionType SessionTypeEnum?
no setter
syncMsgEndSeq num?
no setter
syncMsgSeq num?
no setter
topping bool?
no setter
unReadNum num?
no setter
updateTimeStamp num?
no setter

Methods

copyWith({String? associationId, String? avatar, SyContact? contact, String? key, SyMessage? lastMessage, SyMessage? latestTimeMessage, bool? localData, String? name, num? needSyncMsg, String? sendUserId, String? sessionId, SessionTypeEnum? sessionType, num? syncMsgEndSeq, num? syncMsgSeq, bool? topping, num? unReadNum, num? updateTimeStamp}) SyConversation
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited